# How to write SHRY documentation

This directory contains `python-sphinx` documentation source.

## How to compile

```
make html
```

## Source files

* `Makefile` Makefile.
* `conf.py` contains the sphinx setting confiuration.
* `*.rst` are restructuredtext documentation source files.
* `*.md` are markdown documentation source files.

## How to deploy the documentation

Once the main (or another) repository is pushed to `rc-gh-pages` branch, the implemented `GitHub Actions` automatically compile the `sphinx` documentation and deploy it to the `github-pages`.
